@@ -16,8 +16,8 @@
 ###
 ### You should have received a copy of the GNU General Public
 ### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
+### Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+### MA 02110-1301, USA
 
 
 
@@ -125,6 +125,20 @@ strip.default <-
     strip.levels <- rep(strip.levels, length = 2)
     ## str(shingle.intervals)
 
+    formatLabel <-
+        function(s,
+                 abbreviate = par.strip.text$abbr,
+                 minlength = par.strip.text$minl,
+                 dot = par.strip.text$dot)
+    {
+        if (is.null(abbreviate)) abbreviate <- FALSE
+        if (is.null(minlength)) minlength <- 4
+        if (is.null(dot)) dot <- FALSE
+        if (abbreviate) abbreviate(s, minlength = minlength, dot = dot)
+        else s
+    }
+    factor.levels <- formatLabel(factor.levels)
+
     if (!is.null(shingle.intervals))
     {
 
