@@ -1,7 +1,7 @@
 
-### Copyright (C) 2000-2005 Deepayan Sarkar <Deepayan.Sarkar@R-project.org>,
+### Copyright (C) 2000-2006 Deepayan Sarkar <Deepayan.Sarkar@R-project.org>,
 ###
-### This file is part of the lattice library for R.  It is made
+### This file is part of the lattice package for R.  It is made
 ### available under the terms of the GNU General Public License,
 ### version 2, or at your option, any later version, incorporated
 ### herein by reference.
@@ -14,11 +14,8 @@
 ###
 ### You should have received a copy of the GNU General Public
 ### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
-
-
-
+### Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+### MA 02110-1301, USA
 
 
 
@@ -29,11 +26,9 @@ assign("lattice.options", list(), env = .LatticeEnv)
 assign("last.object",     NULL,   env = .LatticeEnv)
 
 
-
-
 .onLoad <- function(libname, pkgname) 
 {
-    library.dynam("lattice", pkgname, libname )
+    ## library.dynam("lattice", pkgname, libname )
     lattice.options(.defaultLatticeOptions())
     lattice.setStatus(.defaultLatticeStatus())
 }
@@ -46,11 +41,9 @@ assign("last.object",     NULL,   env = .LatticeEnv)
 
 
 
-
-
 ## .First.lib will be used if the NAMESPACE file is missing.  This is
 ## useful during development, thanks to C-c C-l in Emacs/ESS. It won't
-## be used if NAMESPACE is present.
+## be used if a NAMESPACE file is present.
 
 
 .First.lib <- function(lib, pkg) 
